/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.revision;

import java.util.Date;

import org.LexGrid.LexBIG.DataModel.Core.ResolvedConceptReference;
import org.lexgrid.extension.revision.exception.LBRevisionException;

public interface LgRevisedCodedNodeSet {

/**
	 * This method resolves the concept reference for the given entity
	 * ('entityCode') at a given point of time ('date'). Method iterates through
	 * the different revisions of the entity and returns the latest revision of
	 * the entity available on 'date' within LexBIG system. If the given entity
	 * is 'REMOVE'ed from the lexBIG system, method throws LBRevisionException.
	 * If 'date' is null, method resolves the concept for current system
	 * date.Method can't resolve concepts for future dates.
	 * 
	 * @param entityCode
	 * @param date
	 */
public ResolvedConceptReference resolveConceptByDate(String entityCode,
			Date date) throws LBRevisionException;

	/**
	 * This method resolves the concept reference for the given entity
	 * ('entityCode') at a given revision ('revisionId'). Method iterates
	 * through the different revisions of the entity and returns the state of the 
	 * entity (values of attributes and properties)on given revision. If
	 * the given entity is 'REMOVE'ed from the lexBIG system, method throws
	 * LBRevisionException.
	 * 
	 * @param entityCode
	 * @param revisionId
	 */
	public ResolvedConceptReference resolveConceptByRevision(String entityCode,
			String revision) throws LBRevisionException;

}