/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.revision.persistence;

import java.io.IOException;
import java.io.InputStream;

import org.LexGrid.emf.base.xml.LgXMLResourceImpl;
import org.LexGrid.emf.versions.Revision;
import org.LexGrid.emf.versions.SystemRelease;
import org.LexGrid.messaging.LgMessageDirectorIF;
import org.eclipse.emf.common.util.URI;
import org.lexgrid.extension.revision.exception.LBRevisionException;

public class LgRevisionXMLService {

/** Reference to message director */
private LgMessageDirectorIF messages_ = null;
	/** Holds the URI reference for input xmlResource_ file */
	private URI systemReleaseURI_ = null;
	/** Holds the reference for SystemRelease object. */
	private SystemRelease systemRelease_ = null;
	/** Holds the reference for InputStream. */
	private InputStream inputStream_ = null;
	/** Holds the reference for xmlResource */
	private LgXMLResourceImpl xmlResource_ = null;
	/** Holds the reference for revision */
	private Revision revision_ = null;

	/**
	 * Constructor.
	 * 
	 * @param systemReleaseURI
	 * @param messages
	 */
	public LgRevisionXMLService(URI systemReleaseURI,
			LgMessageDirectorIF messages) {
		this.messages_ = messages;
		systemReleaseURI_ = systemReleaseURI;
	}

	/**
	 * Constructor.
	 * 
	 * @param inputStream
	 * @param messages
	 */
	public LgRevisionXMLService(InputStream inputStream,
			LgMessageDirectorIF messages) {
		this.messages_ = messages;
		this.inputStream_ = inputStream;
	}

	public void load() throws LBRevisionException {

		if (systemReleaseURI_ != null) {
			xmlResource_ = new LgXMLResourceImpl(systemReleaseURI_);
			try {
				xmlResource_.load();
			} catch (IOException e) {
				messages_.fatal("XML Load failure.", e);
				throw new LBRevisionException("XML Load failure.", e);
			}
		} else if (inputStream_ != null) {
			xmlResource_ = new LgXMLResourceImpl();
			try {
				xmlResource_.doLoad(inputStream_, xmlResource_
						.getDefaultLoadOptions());
			} catch (IOException e) {
				messages_.fatal("XML Load failure.", e);
				throw new LBRevisionException("XML Load failure.", e);
			}
		} else {
			messages_
					.fatal("Neither xmlResource_ file URI nor InputStream is available.");
			throw new LBRevisionException(
					"Neither xmlResource_ file URI nor InputStream is available.");
		}

		if (xmlResource_.getContents().get(0) instanceof SystemRelease) {
			systemRelease_ = (SystemRelease) xmlResource_.getContents().get(0);
		} else if (xmlResource_.getContents().get(0) instanceof Revision) {
			revision_ = (Revision) xmlResource_.getContents().get(0);
		}
	}

	public void setSystemRelease(SystemRelease sysRel) {
		this.systemRelease_ = sysRel;
	}

	public SystemRelease getSystemRelease() {
		return this.systemRelease_;
	}

	public void setRevision(Revision rev) {
		this.revision_ = rev;
	}

	public Revision getRevision() {
		return this.revision_;
	}
}